/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useContext, useEffect } from 'react';
import axios from 'axios';
import { Store } from '../Store.js'
import { Grid } from '@material-ui/core';
import Button from '@material-ui/core/Button';
import GetAppIcon from '@material-ui/icons/GetApp';
import AddIcon from '@material-ui/icons/Add';
import styled from 'styled-components';
import LinearProgress from '@material-ui/core/LinearProgress';
import CollectionReview from './CollectionReview.js';
import FollowCollectionButton from './FollowCollectionButton.js';
import { apiUrl } from '../env';

export default function CollectionDescription(props) {
	const { state } = useContext(Store);

	const handleDownloadCollection = () => {
		axios.get(apiUrl+'/collections/'+props.collection_id+'/download');
	}

	return (
		<Grid container direction="column" justify="center" alignItems="center">
			<Grid item>
				<Title>{props.title}</Title>
			</Grid>
			<Grid item container
				direction="row" justify="space-between" alignItems="center"
			>
				<Grid item sm={4}>
					<CollectionReview 
						scrollToComment={props.scrollToComments}
						id={props.collection_id}/>
				</Grid>
				<Grid item container sm={8}
					direction="column" justify="center" alignItems="flex-end"
				>
					<Grid item style={{marginBottom: 10}}>
						<DownloadButton
							variant="outlined"
							color="primary"
							startIcon={<GetAppIcon fontSize="large"/>}
							size="large"
							onClick={handleDownloadCollection}
						>
							<ButtonText>Baixar Coleção</ButtonText>
						</DownloadButton>
					</Grid>
					<Grid item>
						<FollowCollectionButton user_id={state.currentUser.id} collection_id={props.collection_id}/>
					</Grid>
				</Grid>
			</Grid>

		</Grid>
	);
}

const Title=styled.h1`
	font-size: 3em;
	color: rgb(102, 102, 102);
	float: left;
`
const ButtonText=styled.span`
	font-weight: bolder;
	font-size: 1.2em;
`
const DownloadButton=styled(Button)`
	padding-left: 10;
	padding-right: 10;
	width: 250px;
`
